@@ -11,9 +11,7 @@ from sqlite3 import Error
 from oauthlib.oauth1.rfc5849 import signature, parameters
 import pandas as pd
 import pytz
-
-from jupyterhub.services.auth import HubOAuthCallbackHandler
-from jupyterhub.services.auth import HubOAuthenticated
+from jupyterhub.services.auth import HubAuthenticated
 from jupyterhub.utils import url_path_join
 from lxml import etree
 import aiohttp
@@ -216,7 +214,7 @@ async def post_grade(user_id, grade, course, section, assignment):
         raise Exception(f"Problem Posting Grade to LTI:{ex}") from ex
 
 
-class GoferHandler(HubOAuthenticated, tornado.web.RequestHandler):
+class GoferHandler(HubAuthenticated, tornado.web.RequestHandler):
     """
     This class handles the HTTP requests for this tornado instance
     """
@@ -231,7 +229,6 @@ class GoferHandler(HubOAuthenticated, tornado.web.RequestHandler):
         self.write("This is a post only page. You probably shouldn't be here!")
         self.finish()
 
-    @authenticated
     def post(self):
         notebook = None
         section = None
@@ -398,16 +395,8 @@ def start_server():
     tornado.options.parse_command_line()
 
     app = tornado.web.Application(
-        [
-            (PREFIX, GoferHandler),
-            (
-                url_path_join(
-                    os.environ['JUPYTERHUB_SERVICE_PREFIX'], 'oauth_callback'
-                ),
-                HubOAuthCallbackHandler,
-            )
-        ],
-        cookie_secret=os.urandom(32))
+        [(PREFIX, GoferHandler)]
+    )
 
     logger = logging.getLogger('tornado.application')
     file_handler = logging.FileHandler(SERVER_LOG_FILE)
